
# Bullhorn Connector

> Transform Your Business with Bullhorn Staffing and Recruitment Software


🔗 https://www.bullhorn.com/

| Actions |
| ------- |
| [**Push profile**](docs/push_profile.md) |
| [**Pull job**](docs/pull_job.md) |
| [**Pull profile parsing**](docs/pull_profile_parsing.md) |
| [**Pull profile**](docs/pull_profile.md) |
